@@ -66,6 +66,16 @@ def register_mark(key=None):
     return wrap
 
 
+# Shape constraint for array-types
+def shape(*dimensions):
+    def validator(trait, value):
+        if value.shape != dimensions:
+            raise TraitError('Expected an of shape %s and got and array with shape %s' % (dimensions, value.shape))
+        else:
+            return value
+    return validator
+
+
 class Mark(Widget):
 
     """The base mark class.
@@ -503,7 +513,7 @@ class Scatter(_ScatterBase):
     marker: {'circle', 'cross', 'diamond', 'square', 'triangle-down',
              'triangle-up', 'arrow', 'rectangle', 'ellipse'}
         Marker shape
-    colors: list of colors (default: ['DeepSkyBlue'])
+    colors: list of colors (default: ['steelblue'])
         List of colors of the markers. If the list is shorter than the number
         of points, the colors are reused.
     default_colors: Deprecated
@@ -588,7 +598,7 @@ class Scatter(_ScatterBase):
                    'triangle-up', 'arrow', 'rectangle', 'ellipse'],
                   default_value='circle').tag(sync=True, display_name='Marker')
     colors = List(trait=Color(default_value=None, allow_none=True),
-                  default_value=['DeepSkyBlue']).tag(sync=True,
+                  default_value=['steelblue']).tag(sync=True,
                   display_name='Colors')
     scales_metadata = Dict({
         'x': {'orientation': 'horizontal', 'dimension': 'x'},
@@ -814,7 +824,7 @@ class Boxplot(Mark):
     }).tag(sync=True)
 
     stroke = Color(None, allow_none=True).tag(sync=True, display_name='Stroke color')
-    box_fill_color = Color('dodgerblue', sync=True, display_name='Fill color for the box')
+    box_fill_color = Color('steelblue', sync=True, display_name='Fill color for the box')
     outlier_fill_color = Color('gray').tag(sync=True, display_name='Outlier fill color')
     opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
     box_width = Int(30, min=5).tag(sync=True, display_name='Box Width')
@@ -848,7 +858,7 @@ class Bars(Mark):
         Y respectively.
     type: {'stacked', 'grouped'}
         whether 2-dimensional bar charts should appear grouped or stacked.
-    colors: list of colors (default: CATEGORY10)
+    colors: list of colors (default: ['steelblue'])
         list of colors for the bars.
     orientation: {'horizontal', 'vertical'}
         Specifies whether the bar chart is drawn horizontally or vertically.
@@ -901,7 +911,7 @@ class Bars(Mark):
     color_mode = Enum(['auto', 'group', 'element'], default_value='auto').tag(sync=True)
     type = Enum(['stacked', 'grouped'], default_value='stacked').tag(sync=True,
                 display_name='Type')
-    colors = List(trait=Color(default_value=None, allow_none=True), default_value=CATEGORY10).tag(sync=True, display_name='Colors')
+    colors = List(trait=Color(default_value=None, allow_none=True), default_value=['steelblue']).tag(sync=True, display_name='Colors')
     padding = Float(0.05).tag(sync=True)
     stroke = Color(None, allow_none=True).tag(sync=True)
     base = Float().tag(sync=True)
@@ -984,7 +994,7 @@ class OHLC(Mark):
     stroke = Color(None, display_name='Stroke color', allow_none=True).tag(sync=True)
     stroke_width = Float(1.0).tag(sync=True, display_name='Stroke Width')
     colors = List(trait=Color(default_value=None, allow_none=True),
-                  default_value=['limegreen', 'red']).tag(sync=True, display_name='Colors')
+                  default_value=['green', 'red']).tag(sync=True, display_name='Colors')
     opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
     format = Unicode('ohlc').tag(sync=True, display_name='Format')
 
@@ -1336,6 +1346,7 @@ class HeatMap(Mark):
     _model_name = Unicode('HeatMapModel').tag(sync=True)
 
 
+@register_mark('bqplot.Graph')
 class Graph(Mark):
     """Graph with nodes and links.
 
@@ -1443,23 +1454,29 @@ class Image(Mark):
 
     Data Attributes
 
-    x0: float or date or unicode (default: 0)
-        abscissa of the left-hand side of the image
-    x1: float or date or unicode (default: 1)
-        abscissa of the right-hand side of the image
-    y0: float or date or unicode (default: 0)
-        ordinate of the bottom of the image
-    y1: float or date or unicode (default: 1)
-        ordinate of the top of the image
+    x: tuple (default: (0, 1))
+        abscissas of the left and right-hand side of the image
+        in the format (x0, x1)
+    y: tuple (default: (0, 1))
+        ordinates of the bottom and top side of the image
+        in the format (x0, x1)
     """
     _view_name = Unicode('Image').tag(sync=True)
     _model_name = Unicode('ImageModel').tag(sync=True)
     image = Instance(widgets.Image).tag(sync=True, **widget_serialization)
-    x0 = (Float(0.0) | Date() | Unicode()).tag(sync=True)
-    y0 = (Float(0.0) | Date() | Unicode()).tag(sync=True)
-    x1 = (Float(1.0) | Date() | Unicode()).tag(sync=True)
-    y1 = (Float(1.0) | Date() | Unicode()).tag(sync=True)
+    x = Array(default_value=(0, 1)).tag(sync=True, scaled=True,
+                                        rtype='Number',
+                                        atype='bqplot.Axis',
+                                        **array_serialization)\
+        .valid(array_squeeze, shape(2))
+    y = Array(default_value=(0, 1)).tag(sync=True, scaled=True,
+                                        rtype='Number',
+                                        atype='bqplot.Axis',
+                                        **array_serialization)\
+        .valid(array_squeeze, shape(2))
     scales_metadata = Dict({
         'x': {'orientation': 'horizontal', 'dimension': 'x'},
         'y': {'orientation': 'vertical', 'dimension': 'y'},
     }).tag(sync=True)
+
+
